<?php
/**
 * Helper functions for the admin - plugin links.
 *
 * @package    WooCommerce German (de_DE)
 * @subpackage Admin
 * @author     David Decker - DECKERWEB
 * @copyright  Copyright 2012, David Decker - DECKERWEB
 * @license    http://www.opensource.org/licenses/gpl-license.php GPL v2.0 (or later)
 * @link       http://genesisthemes.de/en/wp-plugins/woocommerce-de/
 * @link       http://twitter.com/deckerweb
 *
 * @since 1.0.0
 * @version 1.1
 */

/**
 * Setting internal plugin helper links constants
 *
 * @since 2.2.0
 */
define( 'WCDE_URL_TRANSLATE',		'http://translate.wpautobahn.com/projects/wordpress-plugins-deckerweb/woocommerce-de' );
define( 'WCDE_URL_WPORG_FAQ',		'http://wordpress.org/extend/plugins/woocommerce-de/faq/' );
define( 'WCDE_URL_WPORG_FORUM',		'http://wordpress.org/support/plugin/woocommerce-de' );
define( 'WCDE_URL_WPORG_PROFILE',	'http://profiles.wordpress.org/daveshine/' );
define( 'WCDE_PLUGIN_LICENSE', 		'GPLv2+' );
if ( get_locale() == 'de_DE' || get_locale() == 'de_AT' || get_locale() == 'de_CH' || get_locale() == 'de_LU' ) {
	define( 'WCDE_URL_DONATE', 	'http://genesisthemes.de/spenden/' );
	define( 'WCDE_URL_PLUGIN',	'http://genesisthemes.de/plugins/woocommerce-de/' );
	define( 'WCDE_IS_GERMAN', 	true );
} else {
	define( 'WCDE_URL_DONATE', 	'http://genesisthemes.de/en/donate/' );
	define( 'WCDE_URL_PLUGIN',	'http://genesisthemes.de/en/wp-plugins/woocommerce-de/' );
	define( 'WCDE_IS_GERMAN', 	false );
}


/**
 * Add "Settings" link to plugin page
 *
 * @since 2.0.0
 *
 * @param  $wcde_links
 * @param  $wcde_settings_link
 * @return strings settings link
 */
function ddw_wcde_settings_page_link( $wcde_links ) {

	$wcde_settings_link = sprintf( '<a href="%s" title="%s">%s</a>' , admin_url( 'admin.php?page=woocommerce' ) , __( 'Go to the WooCommerce settings page', 'woocommerce-german' ) , __( 'WooCommerce Settings', 'woocommerce-german' ) );
	
	array_unshift( $wcde_links, $wcde_settings_link );

	return $wcde_links;

}  // end of function ddw_wcde_settings_page_link


add_filter( 'plugin_row_meta', 'ddw_wcde_plugin_links', 10, 2 );
/**
 * Add various support links to plugin page
 *
 * @since 1.0.0
 */
function ddw_wcde_plugin_links( $wcde_links, $wcde_file ) {

	if ( ! current_user_can( 'install_plugins' ) )
		return $wcde_links;

	if ( $wcde_file == WCDE_PLUGIN_BASEDIR . '/woocommerce-de.php' ) {
		$wcde_links[] = '<a href="' . esc_url_raw( WCDE_URL_WPORG_FAQ ) . '" target="_new" title="' . __( 'FAQ', 'woocommerce-german' ) . '">' . __( 'FAQ', 'woocommerce-german' ) . '</a>';
		$wcde_links[] = '<a href="' . esc_url_raw( WCDE_URL_WPORG_FORUM ) . '" target="_new" title="' . __( 'Support', 'woocommerce-german' ) . '">' . __( 'Support', 'woocommerce-german' ) . '</a>';
		$wcde_links[] = '<a href="' . esc_url_raw( WCDE_URL_TRANSLATE ) . '" target="_new" title="' . __( 'Translations', 'woocommerce-german' ) . '">' . __( 'Translations', 'woocommerce-german' ) . '</a>';
		$wcde_links[] = '<a href="' . esc_url_raw( WCDE_URL_DONATE ) . '" target="_new" title="' . __( 'Donate', 'woocommerce-german' ) . '">' . __( 'Donate', 'woocommerce-german' ) . '</a>';
	}

	return $wcde_links;

}  // end of function ddw_wcde_plugin_links


add_action( 'load-woocommerce_page_woocommerce_settings', 'ddw_wcde_woocommerce_help_tab', 5 );
add_action( 'load-toplevel_page_woocommerce', 'ddw_wcde_woocommerce_help_tab', 5 );		// deprecated!
add_action( 'load-woocommerce_page_woocommerce_status', 'ddw_wcde_woocommerce_help_tab', 5 );
add_action( 'load-woocommerce_page_woocommerce_reports', 'ddw_wcde_woocommerce_help_tab', 5 );
/**
 * Create and display plugin help tab.
 *
 * @since 2.2.0
 * @version 1.1
 *
 * @global mixed $wcde_woocommerce_screen
 */
function ddw_wcde_woocommerce_help_tab() {

	global $pagenow, $wcde_woocommerce_screen;

	$wcde_woocommerce_screen = get_current_screen();

	/** Display help tabs only for WordPress 3.3 or higher */
	if( ! class_exists( 'WP_Screen' ) || ! $wcde_woocommerce_screen )
		return;

	/** Add the help tab */
	$wcde_woocommerce_screen->add_help_tab( array(
		'id'       => 'wcde-woocommerce-help',
		'title'    => __( 'WooCommerce German (de_DE)', 'woocommerce-german' ),
		'callback' => 'ddw_wcde_woocommerce_help_content',
	) );

	/** Add help sidebar */
	if ( $wcde_woocommerce_screen->id == 'woocommerce_page_woocommerce_status' ) {
		$wcde_woocommerce_screen->set_help_sidebar(
			'<p><strong>' . __( 'More about the plugin author', 'woocommerce-german' ) . '</strong></p>' .
			'<p>' . __( 'Social:', 'woocommerce-german' ) . '<br /><a href="http://twitter.com/deckerweb" target="_blank" title="@ Twitter">Twitter</a> | <a href="http://www.facebook.com/deckerweb.service" target="_blank" title="@ Facebook">Facebook</a> | <a href="http://deckerweb.de/gplus" target="_blank" title="@ Google+">Google+</a> | <a href="' . esc_url_raw( ddw_wcde_plugin_get_data( 'AuthorURI' ) ) . '" target="_blank" title="@ deckerweb.de">deckerweb</a></p>' .
			'<p><a href="' . esc_url_raw( WCDE_URL_WPORG_PROFILE ) . '" target="_blank" title="@ WordPress.org">@ WordPress.org</a></p>'
		);
	}  // end-if page hook check

}  // end of function ddw_wcde_woocommerce_help_tab


/**
 * Create and display plugin help tab content.
 *
 * @since 2.2.0
 * @version 1.1
 *
 * @global mixed $wcde_woocommerce_screen, $pagenow
 */
function ddw_wcde_woocommerce_help_content() {

	echo '<h3>' . __( 'Plugin', 'woocommerce-german' ) . ': ' . __( 'WooCommerce German (de_DE)', 'woocommerce-german' ) . ' <small>v' . esc_attr( ddw_wcde_plugin_get_data( 'Version' ) ) . '</small></h3>' .		
		'<ul>';

		/** FAQ/Legal info for German users */
		if ( WCDE_IS_GERMAN ) {

			$wcde_legal_style = 'style="color: #cc0000;"';

			echo '<li ' . $wcde_legal_style . '"><em><strong>Haftungsausschluss:</strong> Durch den Einsatz dieses Plugins und der damit angebotenen Sprachdateien entstehen KEINE Garantien für eine korrekte Funktionsweise oder etwaige Verpflichtungen durch den Übersetzer bzw. Plugin-Anbieter! — Alle Angaben ohne Gewähr. Änderungen und Irrtümer ausdrücklich vorbehalten. Verwendung des Plugins inkl. Sprachdateien geschieht ausschliesslich auf eigene Verantwortung!</em></li>' .
				'<li><strong ' . $wcde_legal_style . '><em>Hinweis 1:</em></strong> Dieses Plugin ist ein reines Sprach-/ Übersetzungs-Plugin, es hat nichts mit "Rechtssicherheit" zu tun. Für alle rechtlichen Fragen ist der Shop-Betreiber zuständig, nicht die "Sprachdatei"!</li>' .
				'<li><strong ' . $wcde_legal_style . '><em>Hinweis 2:</em></strong> Eine RechtsBERATUNG zu diesem Themenkomplex kann NUR durch einen ANWALT erfolgen (am besten auf Online-Recht spezilisierte Anwälte!). Bitte auch Infos in den einschlägigen Blogs für Shopbetreiber, der (Fach-) Presse sowie von den Industrie- und Handelskammern beachten. -- Ich als Übersetzer und Plugin-Entwickler kann via Sprachdatei KEINE "Rechtssicherheit" garantieren, dies können nur Shop-Betreiber selbst, mit anwaltlicher Unterstützung!</li>' .
				'<li><strong ' . $wcde_legal_style . '><em>Hinweis 3:</em></strong> JA, die sogenannte "Button-Lösung" wird seit Version 2.1 dieses Plugins und Sprachdatei-Version 1.5.5 (aka WooCommerce 1.5.5+) unterstützt. &mdash; Weitere Informationen bei den <a href="' . esc_url_raw( WCDE_URL_WPORG_FAQ ) . '" target="_new" title="Häufige Fragen (FAQ)"><em>Häufigen Fragen (FAQ)</em></a></li>';

		}  // end if isGerman check

		echo '<li><em>' . __( 'Other, recommended WooCommerce plugins', 'woocommerce-german' ) . '</em>:';

			/** Optional: recommended plugins */
			if ( WCDE_IS_GERMAN && ! defined( 'WCABA_PLUGIN_BASEDIR' ) ) {

				echo '<br />&raquo; <a href="http://wordpress.org/extend/plugins/woocommerce-admin-bar-addition/" target="_new" title="WooCommerce Admin Bar Addition">WooCommerce Admin Bar Addition</a> &mdash; Dieses Plugin fügt der WordPress Wergzeugleiste bzw. Adminbar nützliche Administratorenlinks und Ressourcen für das WooCommerce Shop-Plugin hinzu.';

			}  // end-if plugin check

			if ( WCDE_IS_GERMAN && ! class_exists( 'WooCommerce_Delivery_Notes' ) ) {

				echo '<br />&raquo; <a href="http://wordpress.org/extend/plugins/woocommerce-delivery-notes/" target="_new" title="WooCommerce Print Invoices & Delivery Notes">WooCommerce Print Invoices & Delivery Notes</a> &mdash; Dieses Plugin stellt einfache Rechnungen und Lieferscheine für das WooCommerce Shop Plugin bereit. Es können dabei auch Firmen-/ Shop-Infos ebenso wie persönliche Anmerkungen oder Bedingungen/ Widerrufsbelehrungen zu den Druckseiten hinzugefügt werden.';

			}  // end-if plugin check

		echo '<br />&raquo; <a href="http://ddwb.me/wccc" target="_new" title="' . __( 'More premium plugins/extensions at CodeCanyon Marketplace', 'woocommerce-german' ) . ' &hellip;">' . __( 'More premium plugins/extensions at CodeCanyon Marketplace', 'woocommerce-german' ) . ' &hellip;</a>' .
		'<br />&raquo; <a href="http://wordpress.org/extend/plugins/search.php?q=woocommerce" target="_new" title="' . __( 'More free plugins/extensions at WordPress.org', 'woocommerce-german' ) . ' &hellip;">' . __( 'More free plugins/extensions at WordPress.org', 'woocommerce-german' ) . ' &hellip;</a></li>' .
		'</ul>' .
		'<p><strong>' . __( 'Important plugin links:', 'woocommerce-german' ) . '</strong>' . 
		'<br /><a href="' . esc_url_raw( WCDE_URL_PLUGIN ) . '" target="_new" title="' . __( 'Plugin Website', 'woocommerce-german' ) . '">' . __( 'Plugin Website', 'woocommerce-german' ) . '</a> | <a href="' . esc_url_raw( WCDE_URL_WPORG_FAQ ) . '" target="_new" title="' . __( 'FAQ', 'woocommerce-german' ) . '">' . __( 'FAQ', 'woocommerce-german' ) . '</a> | <a href="' . esc_url_raw( WCDE_URL_WPORG_FORUM ) . '" target="_new" title="' . __( 'Support', 'woocommerce-german' ) . '">' . __( 'Support', 'woocommerce-german' ) . '</a> | <a href="' . esc_url_raw( WCDE_URL_TRANSLATE ) . '" target="_new" title="' . __( 'Translations', 'woocommerce-german' ) . '">' . __( 'Translations', 'woocommerce-german' ) . '</a> | <a href="' . esc_url_raw( WCDE_URL_DONATE ) . '" target="_new" title="' . __( 'Donate', 'woocommerce-german' ) . '">' . __( 'Donate', 'woocommerce-german' ) . '</a></p>' .
		'<p><a href="http://www.opensource.org/licenses/gpl-license.php" target="_new" title="' . esc_attr( WCDE_PLUGIN_LICENSE ). '">' . esc_attr( WCDE_PLUGIN_LICENSE ). '</a> &copy; ' . date( 'Y' ) . ' <a href="' . esc_url_raw( ddw_wcde_plugin_get_data( 'AuthorURI' ) ) . '" target="_new" title="' . esc_attr__( ddw_wcde_plugin_get_data( 'Author' ) ) . '">' . esc_attr__( ddw_wcde_plugin_get_data( 'Author' ) ) . '</a></p>';

}  // end of function ddw_wcde_woocommerce_help_tab


add_action( 'admin_init', 'ddw_wcde_woocommerce_cpt_help_tabs' );
/**
 * Display plugin help tab on various WooCommerce Post Type admin pages.
 *
 * @since 2.5.2
 *
 * @global mixed $pagenow, $typenow
 */
function ddw_wcde_woocommerce_cpt_help_tabs() {

	global $pagenow, $typenow;

	/** Check for WordPress Post Types Bases */
	if ( $pagenow == 'post-new.php' || $pagenow == 'post.php' || $pagenow == 'edit.php' ) {

		/** Check for WooCommerce Post Types */
		if ( in_array( $typenow, array( 'product', 'shop_coupon', 'shop_order' ) ) ) {

			add_action( 'load-' . $pagenow, 'ddw_wcde_woocommerce_help_tab', 5 );

		}  // end-if WC check

	}  // end-if base check

}  // end of function ddw_wcde_woocommerce_cpt_help_tabs
